##  Configuring Mapping of Fact Sheets to Collibra
To configure fact sheet mapping, on the Collibra Integration Configuration page, navigate to the Application Mapping tab.
![Configuring Application Mapping](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274421bd7a441014bcdeb9664b57c16c_LowRes.png)
Configuring Application Mapping
